@@ -184,24 +184,28 @@ def _update_ldap_user_pw(username, uidNumber, password):
     l.modify_s(dn, attrs)	
 
 
-def _insert_jos_users(db, joomlauserid, name, username, email, password, jgid, jgidNumber):
+def _insert_jos_users(db, joomlauserid, name, username, email, password, jgidNumber):
 
     if password != '*':
         pw = hubzero.config.passwords.MD5PasswordHash(password)
     elif '{MD5}' in password:
         pw = password
     else:
-        pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+        pw = '{MD5}*' # can user generate a value that will MD5 hash to '*'? we think not
+
+    # xlate numeric jgidNumber to the string (Joomla needs both for some reason)
+    # 18=Registered, 23=Manager, 24=Administrator, 25=Super Administrator
+    userTypeLookupDict = {18:"Registered", 23:"Manager", 24:"Administrator", 25:"Super Administrator"}
 
     if joomlauserid == -1:
         sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
         sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-        data = (name, username, email, pw, jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+        data = (name, username, email, pw, userTypeLookupDict[jgidNumber], 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
         userID = db.query_lastrowid(sql, data)
     else:
         sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
         sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-        data = (joomlauserid, name, username, email, pw, jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+        data = (joomlauserid, name, username, email, pw, userTypeLookupDict[jgidNumber], 0, 1, jgidNumber , datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
         userID = db.query_lastrowid(sql, data)
 
     return userID
@@ -259,7 +263,7 @@ def _insert_jos_users_password(db, userid, password):
     db.query_rowcount(sql, data)
 
 
-def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid, gidNumber, hubname = ""):
+def add_ldap_user(uid, gecos, password, uidNumber, homeDir, loginShell, gid, gidNumber, hubname = ""):
 
     # get ldapManagerUserDN and PW
 
@@ -270,10 +274,10 @@ def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid
     l = ldap.initialize('ldap://localhost')
     l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
-    dn = "uid=" + username + ",ou=users," + hubLDAPBaseDN
+    dn = "uid=" + str(uid) + ",ou=users," + hubLDAPBaseDN
     attrs = {}
     attrs['objectclass'] = ['top', 'account', 'posixAccount', 'shadowAccount']  
-    attrs['cn'] = username
+    attrs['cn'] = str(uid)
 
     if password != '*':
         attrs['userPassword'] = hubzero.config.passwords.MD5PasswordHash(password)
@@ -282,10 +286,10 @@ def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid
     else:
         attrs['userPassword'] = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
 
-    attrs['uid'] = username
+    attrs['uid'] = uid
     attrs['uidNumber'] = str(uidNumber)
     attrs['homeDirectory'] = homeDir
-    attrs['cn'] = gecos
+    #attrs['cn'] = gecos
     attrs['loginShell'] = loginShell
 
     # TODO: grab this from the com_members component parm field
@@ -305,25 +309,22 @@ def delete_ldap_user(username, hubname = ""):
     l = ldap.initialize('ldap://localhost')
     l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
     dn = "uid=" + username + ",ou=users," + hubLDAPBaseDN
-    print "delete ldap user dn: " + dn
     l.delete_s(dn)
 
 
-def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid, 
-               joomlagidNumber, gid, gidNumber, uid, loginShell, nocreatehome, homeDir, skipCreateGroup, 
-               skipldap, skipcms):
+def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagidNumber, gid, gidNumber, uidNumber, 
+               loginShell, nocreatehome, homeDir, skipCreateGroup, skipldap, skipcms):
     """
     hubname - for machines that have more than one hub, otherwise this will use the default hub for a server
     username - username to add
-    gecos - comma delimited info list on user, we curretnly only use first entry, which is a full name (fname, mname, lname)(
+    gecos - comma delimited info list on user, we curretnly only use first entry, which is a full name (fname, mname, lname)
     email - user email
     pw - unencrypted password, we'll hash it as necessary using MD5
     pwdisabled - should the PW be disabled?
-    joomlagid - specify hardcoded uidNumber for the user
-    joomlagidNumber - joomla group
+    joomlagidNumber - 18=Registered, 23=Manager, 24=Administrator, 25=Super Administrator
     gid - linux gid membership
     gidNumber - linux gidNumber, corresponds to the group with the previous gid
-    uid - specify the jos_users PK ID, also is the uidNumber for the ldap (same thing)
+    uidNumber - specify the jos_users PK ID, also is the uidNumber for the ldap (same thing)
     loginShell - user's login shell
     nocreatehome - skip creation of home directory
     homeDir - path to user's home directory
@@ -382,7 +383,7 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
             print "User '" + username + "' already exists in ldap"
             return (2)
     else:
-        print "skip cms insert and ldap, why bother?"
+        print "skip cms insert and ldap, but then why bother?"
         return(3)
 
     # if the user doesn't want custom group for this user, they still need to be added to some group
@@ -400,11 +401,11 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
             gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
             gid = username # group name same as user
 
-        userID = _insert_jos_users(db, uid, fullName, username, email, pw, joomlagid, joomlagidNumber)
-        aroID = _insert_jos_core_acl_aro(db, userID, fullName)
+        uidNumber = _insert_jos_users(db, uid, fullName, username, email, pw, joomlagid, joomlagidNumber)
+        aroID = _insert_jos_core_acl_aro(db, uidNumber, fullName)
         _insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
-        _insert_jos_xprofiles(db, hubname, userID, firstName, middleName, lastName, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
-        _insert_jos_users_password(db, userID, pw)
+        _insert_jos_xprofiles(db, hubname, uidNumber, firstName, middleName, lastName, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
+        _insert_jos_users_password(db, uidNumber, pw)
 
         # add user to new group (need xgroups insert after user creation because we need userid, I'd prefer to keep all group logic in one place)
         if not skipCreateGroup:
@@ -431,7 +432,7 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
         if not skipCreateGroup:
             hubzero.utilities.group.add_ldap_group(username, username + " group", gidNumber)
 
-        add_ldap_user(username, gecos, pw, userID, homeDir, loginShell, gid, gidNumber)
+        add_ldap_user(username, gecos, pw, uidNumber, homeDir, loginShell, gid, gidNumber)
 
     return(0)
 
@@ -524,7 +525,7 @@ def uidExists(uid, hubname = ""):
         return True
 
 
-def getLDAPMaxuid(hubname = ""):
+def getLDAPMaxuidNumber(hubname = ""):
     """
     get max(uid) of all objects of class posixAccount in ou=Users
     """
